@@ -2,6 +2,9 @@
 // ecasound.cpp: Console mode user interface to ecasound.
 // Copyright (C) 2002-2005 Kai Vehmanen
 //
+// Attributes:
+//     eca-style-version: 3
+//
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation; either version 2 of the License, or
@@ -79,6 +82,7 @@ static struct ecasound_state ecasound_state_global =
     0,        /* int - return value */
     2868,     /* int - default daemon mode TCP-port */
     false,    /* daemon mode */
+    false,    /* keep_running mode */
     false,    /* cerr-output-only mode */
     false,    /* interactive mode */
     false     /* quiet mode */
@@ -153,15 +157,25 @@ int main(int argc, char *argv[])
 
   if (state->daemon_mode == true) {
     /* wait until daemon thread has exited */
-    state->exit_request = 1;
+    if (state->interactive_mode == true) {
+      state->exit_request = 1;
+    }
     pthread_join(*state->daemon_thread, NULL);
   }
 
   /* note: if we exist due to a signal, we never reach 
    *       the end of main() */
+
+  /* note: we prefer to run the cleanup routines before 
+   *       returning from main; there have been problems with
+   *       dynamic libraries and libecasound cleanup routines
+   *       when run from atexit handler
+   */
+  ecasound_atexit_cleanup();
+
   // cerr << endl << "ecasound: main() exiting..." << endl << endl;
 
-  return(state->retval);
+  return state->retval;
 }
 
 /**
@@ -297,12 +311,13 @@ void ecasound_main_loop(struct ecasound_state* state)
       DBC_CHECK(res == 0);
     }
 
-    if (ctrl->is_valid() == true) {
+    if (ctrl->is_selected() == true && 
+	ctrl->is_valid() == true) {
       ctrl->connect_chainsetup();
     }
 
     if (ctrl->is_connected() == true) {
-      ctrl->run();
+      ctrl->run(!state->keep_running_mode);
     }
     else {
       ctrl->print_last_value();
@@ -354,7 +369,6 @@ void ecasound_parse_command_line(struct ecasound_state* state,
       
       else if (cline.current() == "--daemon") {
 	state->daemon_mode = true;
-	state->interactive_mode = true;
       }
 
       else if (cline.current().find("--daemon-port") != string::npos) {
@@ -377,6 +391,11 @@ void ecasound_parse_command_line(struct ecasound_state* state,
 	break;
       }
 
+      else if (cline.current() == "-K" ||
+	       cline.current() == "--keep-running") {
+	state->keep_running_mode = true;
+      }
+
       else if (cline.current() == "--version") {
 	ecasound_print_version_banner();
 	state->retval = -1;
@@ -401,7 +420,7 @@ void ecasound_print_usage(void)
 void ecasound_print_version_banner(void)
 {
   cout << "ecasound v" << ecasound_library_version << endl;
-  cout << "Copyright (C) 1997-2005 Kai Vehmanen" << endl;
+  cout << "Copyright (C) 1997-2005 Kai Vehmanen and others." << endl;
   cout << "Ecasound comes with ABSOLUTELY NO WARRANTY." << endl;
   cout << "You may redistribute copies of ecasound under the terms of the GNU" << endl;
   cout << "General Public License. For more information about these matters, see" << endl; 
@@ -509,5 +528,5 @@ void* ecasound_watchdog_thread(void* arg)
   exit(state->retval);
 
   /* to keep the compilers happy; never actually executed */
-  return(0);
+  return 0;
 }
