@@ -1,6 +1,7 @@
 // ------------------------------------------------------------------------
 // eca-chain.cpp: Class representing an abstract audio signal chain.
-// Copyright (C) 1999-2004 Kai Vehmanen
+// Copyright (C) 1999-2005 Kai Vehmanen
+// Copyright (C) 2005 Stuart Allie
 //
 // Attributes:
 //     eca-style-version: 3
@@ -249,6 +250,22 @@ string CHAIN::chain_operator_parameter_name(void) const
   return selected_chainop_repp->get_parameter_name(selected_chain_operator_parameter());
 }
 
+/**
+ * Returns the name of selected controller parameter.
+ *
+ * require:
+  *  selected_controller() != 0
+  *  selected_controller_parameter() != 0
+ */
+string CHAIN::controller_parameter_name(void) const
+{
+  // --------
+  DBC_REQUIRE(selected_controller() > 0);
+  DBC_REQUIRE(selected_controller_parameter() > 0);
+  // --------
+  return selected_controller_repp->get_parameter_name(selected_controller_parameter());
+}
+
 /**
  * Returns the total number of parameters for the 
  * selected chain operator.
@@ -264,6 +281,20 @@ int CHAIN::number_of_chain_operator_parameters(void) const
   return selected_chainop_repp->number_of_params();
 }
 
+/**
+ * Returns the total number of parameters for the selected controller.
+ *
+ * require:
+  *  selected_controller() != 0
+ */
+int CHAIN::number_of_controller_parameters(void) const
+{
+  // --------
+  DBC_REQUIRE(selected_controller() > 0);
+  // --------
+  return selected_controller_repp->number_of_params();
+}
+
 /**
  * Returns the name of selected controller.
  *
@@ -407,6 +438,7 @@ void CHAIN::select_chain_operator(int index)
     if (chainop_sizet + 1 == index) {
       selected_chainop_repp = chainops_rep[chainop_sizet];
       selected_chainop_number_rep = index;
+      selected_chain_operator_as_target();
     }
   }
 }
@@ -466,6 +498,40 @@ void CHAIN::select_controller_parameter(int index)
   selected_controller_parameter_rep = index;
 }
 
+/**
+ * Gets the value of the currently selected controller parameter.
+ *
+ * require:
+ *  selected_controller() != 0
+ *  selected_controller_parameter() != 0
+ */
+CHAIN_OPERATOR::parameter_t CHAIN::get_controller_parameter(void) const
+{
+  // --------
+  DBC_REQUIRE(selected_controller_parameter() > 0);
+  DBC_REQUIRE(selected_controller() != 0);
+  // --------
+  return selected_controller_repp->get_parameter(selected_controller_parameter_rep);
+}
+
+/**
+ * Sets the value of the currently selected controller parameter.
+ *
+ * require:
+ * selected_controller_number_rep > 0 && selected_controller_number_rep <= number_of_controllers()
+ *  selected_controller() != 0
+ *  selected_controller_parameter() != 0
+ */
+void CHAIN::set_controller_parameter(CHAIN_OPERATOR::parameter_t value)
+{
+  // --------
+  DBC_REQUIRE(selected_controller_number_rep > 0 && selected_controller_number_rep <= number_of_controllers());
+  DBC_REQUIRE(selected_controller_parameter() > 0);
+  DBC_REQUIRE(selected_controller() != 0);
+  // --------
+  selected_controller_repp->set_parameter(selected_controller_parameter_rep, value);
+}
+
 /**
  * Use current selected chain operator as 
  * target for parameters control.
@@ -632,7 +698,7 @@ void CHAIN::refresh_parameters(void)
   for(int chainop_sizet = 0; chainop_sizet != static_cast<int>(chainops_rep.size()); chainop_sizet++) {
     for(int n = 0; n < chainops_rep[chainop_sizet]->number_of_params(); n++) {
       chainops_rep[chainop_sizet]->set_parameter(n + 1, 
-					       chainops_rep[chainop_sizet]->get_parameter(n + 1));
+						 chainops_rep[chainop_sizet]->get_parameter(n + 1));
     }
   }
 }
