@@ -1,7 +1,10 @@
 // ------------------------------------------------------------------------
 // eca-control-base.cpp: Base class providing basic functionality
 //                       for controlling the ecasound library
-// Copyright (C) 1999-2002 Kai Vehmanen (kai.vehmanen@wakkanet.fi)
+// Copyright (C) 1999-2004 Kai Vehmanen
+//
+// Attributes:
+//     eca-style-version: 3
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -43,6 +46,7 @@
 /**
  * Import namespaces
  */
+using std::list;
 using std::string;
 using std::vector;
 
@@ -63,7 +67,7 @@ void* ECA_CONTROL_BASE::start_normal_thread(void *ptr)
   ECA_LOG_MSG(ECA_LOGGER::system_objects,"(eca-controller) Engine-thread pid: " + kvu_numtostr(getpid()));
   ECA_CONTROL_BASE* ctrl_base = static_cast<ECA_CONTROL_BASE*>(ptr);
   ctrl_base->run_engine();
-  return(0);
+  return 0;
 }
 
 ECA_CONTROL_BASE::ECA_CONTROL_BASE (ECA_SESSION* psession)
@@ -72,6 +76,7 @@ ECA_CONTROL_BASE::ECA_CONTROL_BASE (ECA_SESSION* psession)
   selected_chainsetup_repp = psession->selected_chainsetup_repp;
   engine_repp = 0;
   engine_exited_rep.set(0);
+  float_to_string_precision_rep = 3;
 }
 
 ECA_CONTROL_BASE::~ECA_CONTROL_BASE (void)
@@ -132,6 +137,9 @@ void ECA_CONTROL_BASE::start(void)
  * Starts the processing engine and blocks until 
  * processing is finished.
  *
+ * @param batchmode if true, runs until finished/stopped state is reached, and
+ *        then returns; if false, will run infinitely
+ *
  * @pre is_connected() == true
  * @pre is_running() != true
  * @post is_finished() == true || 
@@ -141,7 +149,7 @@ void ECA_CONTROL_BASE::start(void)
  *        is_engine_started() == true &&
  * 	  engine_repp->status() != ECA_ENGINE::engine_status_stopped))
  */
-void ECA_CONTROL_BASE::run(void)
+void ECA_CONTROL_BASE::run(bool batchmode)
 {
   // --------
   DBC_REQUIRE(is_connected() == true);
@@ -154,7 +162,7 @@ void ECA_CONTROL_BASE::run(void)
 
   if (is_engine_started() != true) {
     /* request_batchmode=true */
-    start_engine_sub(true);
+    start_engine_sub(batchmode);
   }
 
   if (is_engine_started() != true) {
@@ -165,7 +173,9 @@ void ECA_CONTROL_BASE::run(void)
 
     DBC_CHECK(is_finished() != true);
 
-    while(is_finished() != true) {
+    /* run until processing is finished; in batchmode run forever (or
+     * until error occurs) */
+    while(is_finished() != true || batchmode != true) {
       
       /* sleep for one second */
       kvu_sleep(1, 0);
@@ -196,8 +206,9 @@ void ECA_CONTROL_BASE::run(void)
       else {
 	/* engine was started succesfully (processing_started == true) */
 	if (is_running() != true) {
-	  /* operation succesfully completed, exit from run() */
-	  break;
+	  /* operation succesfully completed, exit from run() unless
+	   * infinite operation is requested (batchmode) */
+	  if (batchmode == true) break;
 	}
       }
     }
@@ -302,7 +313,7 @@ void ECA_CONTROL_BASE::start_engine_sub(bool batchmode)
 				   start_normal_thread, 
 				   static_cast<void *>(this));
   if (retcode_rep != 0) {
-    ECA_LOG_MSG(ECA_LOGGER::info, "Warning! Unable to create a new thread for engine.");
+    ECA_LOG_MSG(ECA_LOGGER::info, "WARNING: Unable to create a new thread for engine.");
     delete engine_repp;
     engine_repp = 0;
   }
@@ -339,7 +350,7 @@ void ECA_CONTROL_BASE::close_engine(void)
     engine_exited_rep.set(0);
   }
   else {
-    ECA_LOG_MSG(ECA_LOGGER::info, "Warning! Problems while shutting down the engine!");
+    ECA_LOG_MSG(ECA_LOGGER::info, "WARNING: Problems while shutting down the engine!");
   }
 
   // ---
@@ -358,7 +369,9 @@ bool ECA_CONTROL_BASE::is_valid(void) const
   DBC_REQUIRE(is_selected());
   // --------
 
-  return(selected_chainsetup_repp->is_valid());
+  /* use is_valid_for_connection() instead of is_valid() to 
+   * report any detected errors via the logging subsystem */
+  return selected_chainsetup_repp->is_valid_for_connection(true);
 }
 
 /**
@@ -366,20 +379,23 @@ bool ECA_CONTROL_BASE::is_valid(void) const
  */
 bool ECA_CONTROL_BASE::is_connected(void) const
 {
-  if (session_repp->connected_chainsetup_repp == 0) return(false);
-  return(session_repp->connected_chainsetup_repp->is_valid() &&
-	 session_repp->connected_chainsetup_repp->is_enabled());
+  if (session_repp->connected_chainsetup_repp == 0) {
+    return false;
+  }
+
+  return (session_repp->connected_chainsetup_repp->is_valid() &&
+	  session_repp->connected_chainsetup_repp->is_enabled());
 }
 
 /**
  * Returns true if some chainsetup is selected.
  */
-bool ECA_CONTROL_BASE::is_selected(void) const { return(selected_chainsetup_repp != 0); } 
+bool ECA_CONTROL_BASE::is_selected(void) const { return selected_chainsetup_repp != 0; } 
 
 /**
  * Returns true if processing engine is running.
  */
-bool ECA_CONTROL_BASE::is_running(void) const { return(is_engine_started() == true && engine_repp->status() == ECA_ENGINE::engine_status_running); } 
+bool ECA_CONTROL_BASE::is_running(void) const { return (is_engine_started() == true && engine_repp->status() == ECA_ENGINE::engine_status_running); } 
 
 /**
  * Returns true if engine has finished processing. Engine state is 
@@ -387,15 +403,15 @@ bool ECA_CONTROL_BASE::is_running(void) const { return(is_engine_started() == tr
  */
 bool ECA_CONTROL_BASE::is_finished(void) const
 {
-  return(is_engine_started() == true && 
-	 (engine_repp->status() == ECA_ENGINE::engine_status_finished ||
-	  engine_repp->status() == ECA_ENGINE::engine_status_error)); 
+  return (is_engine_started() == true && 
+	  (engine_repp->status() == ECA_ENGINE::engine_status_finished ||
+	   engine_repp->status() == ECA_ENGINE::engine_status_error)); 
 } 
 
 string ECA_CONTROL_BASE::resource_value(const string& key) const
 { 
   ECA_RESOURCES ecarc;
-  return(ecarc.resource(key)); 
+  return ecarc.resource(key); 
 }
 
 /**
@@ -417,7 +433,7 @@ SAMPLE_SPECS::sample_pos_t ECA_CONTROL_BASE::length_in_samples(void) const
     cslen = selected_chainsetup_repp->max_length_in_samples();
   }
 
-  return(cslen);
+  return cslen;
 }
 
 /**
@@ -439,7 +455,7 @@ double ECA_CONTROL_BASE::length_in_seconds_exact(void) const
     cslen = selected_chainsetup_repp->max_length_in_seconds_exact();
   }
 
-  return(cslen);
+  return cslen;
 }
 
 /**
@@ -453,7 +469,7 @@ SAMPLE_SPECS::sample_pos_t ECA_CONTROL_BASE::position_in_samples(void) const
   DBC_REQUIRE(is_selected());
   // --------
 
-  return(selected_chainsetup_repp->position_in_samples());
+  return selected_chainsetup_repp->position_in_samples();
 }
 
 /**
@@ -467,7 +483,31 @@ double ECA_CONTROL_BASE::position_in_seconds_exact(void) const
   DBC_REQUIRE(is_selected());
   // --------
 
-  return(selected_chainsetup_repp->position_in_seconds_exact());
+  return selected_chainsetup_repp->position_in_seconds_exact();
+}
+
+/**
+ * Returns true if engine has been started. 
+ *
+ * Note: when in batch mode, status of notready means that
+ *       engine has exited and is no longer receiving any commands
+ *       and thus false is returned
+ */
+bool ECA_CONTROL_BASE::is_engine_started(void) const
+{
+  bool ret = true;
+
+  if (engine_repp == 0) {
+    ret = false;
+  }
+  else {
+    if (engine_repp->batch_mode() == true &&
+	engine_repp->status() == ECA_ENGINE::engine_status_notready) {
+      ret = false;
+    }
+  }
+  
+  return ret;
 }
 
 /**
@@ -479,31 +519,31 @@ string ECA_CONTROL_BASE::engine_status(void) const
     switch(engine_repp->status()) {
     case ECA_ENGINE::engine_status_running: 
       {
-	return("running"); 
+	return "running"; 
       }
     case ECA_ENGINE::engine_status_stopped: 
       {
-	return("stopped"); 
+	return "stopped"; 
       }
     case ECA_ENGINE::engine_status_finished:
       {
-	return("finished"); 
+	return "finished"; 
       }
     case ECA_ENGINE::engine_status_error:
       {
-	return("error"); 
+	return "error"; 
       }
     case ECA_ENGINE::engine_status_notready: 
       {
-	return("not ready"); 
+	return "not ready"; 
       }
     default: 
       {
-	return("unknown status"); 
+	return "unknown status"; 
       }
     }
   }
-  return("not started");
+  return "not started";
 }
 
 /**
@@ -526,7 +566,7 @@ string ECA_CONTROL_BASE::attached_chains_input(AUDIO_IO* aiod) const
     ++p;
     if (p != t.end()) out += ",";
   }
-  return(out);
+  return out;
 }
 
 /**
@@ -549,7 +589,7 @@ string ECA_CONTROL_BASE::attached_chains_output(AUDIO_IO* aiod) const
     ++p;
     if (p != t.end()) out += ",";
   }
-  return(out);
+  return out;
 }
 
 /**
@@ -564,7 +604,24 @@ vector<string> ECA_CONTROL_BASE::attached_chains(const string& filename) const
   DBC_REQUIRE(is_selected() == true);
   // --------
 
-  return(selected_chainsetup_repp->get_attached_chains_to_iodev(filename));
+  return selected_chainsetup_repp->get_attached_chains_to_iodev(filename);
+}
+
+void ECA_CONTROL_BASE::set_last_string(const list<string>& s)
+{
+  // use resize() instead of clear(); clear() was a late
+  // addition to C++ standard and not supported by all
+  // compilers (for example egcs-2.91.66) 
+  last_s_rep.resize(0);
+
+  DBC_CHECK(last_s_rep.size() == 0);
+  list<string>::const_iterator p = s.begin();
+  while(p != s.end()) {
+    last_s_rep += *p;
+    ++p;
+    if (p != s.end()) last_s_rep += "\n";
+  }
+  last_type_rep = "s";
 }
 
 void ECA_CONTROL_BASE::set_last_string_list(const vector<string>& s)
@@ -603,13 +660,13 @@ void ECA_CONTROL_BASE::set_last_error(const string& s)
   last_type_rep = "e";
 }
 
-const vector<string>& ECA_CONTROL_BASE::last_string_list(void) const { return(last_los_rep); }
-const string& ECA_CONTROL_BASE::last_string(void) const { return(last_s_rep); }
-double ECA_CONTROL_BASE::last_float(void) const { return(last_f_rep); }
-int ECA_CONTROL_BASE::last_integer(void) const { return(last_i_rep); } 
-long int ECA_CONTROL_BASE::last_long_integer(void) const { return(last_li_rep); }
-const string& ECA_CONTROL_BASE::last_error(void) const { return(last_error_rep); }
-const string& ECA_CONTROL_BASE::last_type(void) const { return(last_type_rep); }
+const vector<string>& ECA_CONTROL_BASE::last_string_list(void) const { return last_los_rep; }
+const string& ECA_CONTROL_BASE::last_string(void) const { return last_s_rep; }
+double ECA_CONTROL_BASE::last_float(void) const { return last_f_rep; }
+int ECA_CONTROL_BASE::last_integer(void) const { return last_i_rep; } 
+long int ECA_CONTROL_BASE::last_long_integer(void) const { return last_li_rep; }
+const string& ECA_CONTROL_BASE::last_error(void) const { return last_error_rep; }
+const string& ECA_CONTROL_BASE::last_type(void) const { return last_type_rep; }
 
 void ECA_CONTROL_BASE::clear_last_values(void)
 { 
@@ -621,3 +678,12 @@ void ECA_CONTROL_BASE::clear_last_values(void)
   last_error_rep = "";
   last_type_rep = "-";
 }
+
+void ECA_CONTROL_BASE::set_float_to_string_precision(int precision)
+{
+  float_to_string_precision_rep = precision;
+}
+std::string ECA_CONTROL_BASE::float_to_string(double n) const
+{
+  return kvu_numtostr(n, float_to_string_precision_rep);
+}
